@@ -218,7 +218,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('validation/run_validation').with(:value => false)
           is_expected.to contain_tempest_config('identity/admin_role').with(:value => nil)
-          is_expected.to contain_tempest_config('identity/auth_version').with(:value => 'v2')
+          is_expected.to contain_tempest_config('identity/auth_version').with(:value => 'v3')
           is_expected.to contain_tempest_config('identity/alt_password').with(:value => nil)
           is_expected.to contain_tempest_config('identity/alt_password').with_secret( true )
           is_expected.to contain_tempest_config('identity/alt_project_name').with(:value => nil)
@@ -231,7 +231,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('identity/username').with(:value => nil)
           is_expected.to contain_tempest_config('identity/ca_certificates_file').with(:value => nil)
           is_expected.to contain_tempest_config('identity/disable_ssl_certificate_validation').with(:value => nil)
-          is_expected.to contain_tempest_config('identity-feature-enabled/api_v2').with(:value => true)
+          is_expected.to contain_tempest_config('identity-feature-enabled/api_v2').with(:value => false)
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => true)
           is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => true)
           is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => true)
